@@ -48,27 +48,27 @@ const ColorEntry ColorScheme::defaultTable[TABLE_COLORS] =
  // gamma correction for the dim colors to compensate for bright X screens.
  // It contains the 8 ansiterm/xterm colors in 2 intensities.
 {
-    ColorEntry( QColor(0x00,0x00,0x00), 0), ColorEntry(
-QColor(0xFF,0xFF,0xFF), 1), // Dfore, Dback
-    ColorEntry( QColor(0x00,0x00,0x00), 0), ColorEntry(
-QColor(0xB2,0x18,0x18), 0), // Black, Red
-    ColorEntry( QColor(0x18,0xB2,0x18), 0), ColorEntry(
-QColor(0xB2,0x68,0x18), 0), // Green, Yellow
-    ColorEntry( QColor(0x18,0x18,0xB2), 0), ColorEntry(
-QColor(0xB2,0x18,0xB2), 0), // Blue, Magenta
-    ColorEntry( QColor(0x18,0xB2,0xB2), 0), ColorEntry(
-QColor(0xB2,0xB2,0xB2), 0), // Cyan, White
+    ColorEntry( QColor(0x00,0x00,0x00), false), ColorEntry(
+QColor(0xFF,0xFF,0xFF), true), // Dfore, Dback
+    ColorEntry( QColor(0x00,0x00,0x00), false), ColorEntry(
+QColor(0xB2,0x18,0x18), false), // Black, Red
+    ColorEntry( QColor(0x18,0xB2,0x18), false), ColorEntry(
+QColor(0xB2,0x68,0x18), false), // Green, Yellow
+    ColorEntry( QColor(0x18,0x18,0xB2), false), ColorEntry(
+QColor(0xB2,0x18,0xB2), false), // Blue, Magenta
+    ColorEntry( QColor(0x18,0xB2,0xB2), false), ColorEntry(
+QColor(0xB2,0xB2,0xB2), false), // Cyan, White
     // intensive
-    ColorEntry( QColor(0x00,0x00,0x00), 0), ColorEntry(
-QColor(0xFF,0xFF,0xFF), 1),
-    ColorEntry( QColor(0x68,0x68,0x68), 0), ColorEntry(
-QColor(0xFF,0x54,0x54), 0),
-    ColorEntry( QColor(0x54,0xFF,0x54), 0), ColorEntry(
-QColor(0xFF,0xFF,0x54), 0),
-    ColorEntry( QColor(0x54,0x54,0xFF), 0), ColorEntry(
-QColor(0xFF,0x54,0xFF), 0),
-    ColorEntry( QColor(0x54,0xFF,0xFF), 0), ColorEntry(
-QColor(0xFF,0xFF,0xFF), 0)
+    ColorEntry( QColor(0x00,0x00,0x00), false), ColorEntry(
+QColor(0xFF,0xFF,0xFF), true),
+    ColorEntry( QColor(0x68,0x68,0x68), false), ColorEntry(
+QColor(0xFF,0x54,0x54), false),
+    ColorEntry( QColor(0x54,0xFF,0x54), false), ColorEntry(
+QColor(0xFF,0xFF,0x54), false),
+    ColorEntry( QColor(0x54,0x54,0xFF), false), ColorEntry(
+QColor(0xFF,0x54,0xFF), false),
+    ColorEntry( QColor(0x54,0xFF,0xFF), false), ColorEntry(
+QColor(0xFF,0xFF,0xFF), false)
 };
 
 const char* const ColorScheme::colorNames[TABLE_COLORS] =
@@ -122,25 +122,25 @@ const char* const ColorScheme::translatedColorNames[TABLE_COLORS] =
 
 ColorScheme::ColorScheme()
 {
-    _table = 0;
-    _randomTable = 0;
+    _table = nullptr;
+    _randomTable = nullptr;
     _opacity = 1.0;
 }
 ColorScheme::ColorScheme(const ColorScheme& other)
       : _opacity(other._opacity)
-       ,_table(0)
-       ,_randomTable(0)
+       ,_table(nullptr)
+       ,_randomTable(nullptr)
 {
     setName(other.name());
     setDescription(other.description());
 
-    if ( other._table != 0 )
+    if ( other._table != nullptr )
     {
         for ( int i = 0 ; i < TABLE_COLORS ; i++ )
             setColorTableEntry(i,other._table[i]);
     }
 
-    if ( other._randomTable != 0 )
+    if ( other._randomTable != nullptr )
     {
         for ( int i = 0 ; i < TABLE_COLORS ; i++ )
         {
@@ -185,7 +185,7 @@ ColorEntry ColorScheme::colorEntry(int index , uint randomSeed) const
     ColorEntry entry = colorTable()[index];
 
     if ( randomSeed != 0 &&
-        _randomTable != 0 &&
+        _randomTable != nullptr &&
         !_randomTable[index].isNull() )
     {
         const RandomizationRange& range = _randomTable[index];
@@ -213,7 +213,7 @@ void ColorScheme::getColorTable(ColorEntry* table , uint randomSeed) const
 }
 bool ColorScheme::randomizedBackgroundColor() const
 {
-    return _randomTable == 0 ? false : !_randomTable[1].isNull();
+    return _randomTable == nullptr ? false : !_randomTable[1].isNull();
 }
 void ColorScheme::setRandomizedBackgroundColor(bool randomize)
 {
@@ -238,7 +238,7 @@ void ColorScheme::setRandomizationRange( int index , quint16 hue , quint8 satura
     Q_ASSERT( hue <= MAX_HUE );
     Q_ASSERT( index >= 0 && index < TABLE_COLORS );
 
-    if ( _randomTable == 0 )
+    if ( _randomTable == nullptr )
         _randomTable = new RandomizationRange[TABLE_COLORS];
 
     _randomTable[index].hue = hue;
@@ -594,7 +594,7 @@ ColorSchemeManager::~ColorSchemeManager()
 }
 void ColorSchemeManager::loadAllColorSchemes()
 {
-    qDebug() << "loadAllColorSchemes";
+    //qDebug() << "loadAllColorSchemes";
     int failed = 0;
 
     QList<QString> nativeColorSchemes = listColorSchemes();
@@ -613,8 +613,8 @@ void ColorSchemeManager::loadAllColorSchemes()
             failed++;
     }
 
-    if ( failed > 0 )
-        qDebug() << "failed to load " << failed << " color schemes.";
+    /*if ( failed > 0 )
+        qDebug() << "failed to load " << failed << " color schemes.";*/
 
     _haveLoadedAll = true;
 }
@@ -640,7 +640,7 @@ bool ColorSchemeManager::loadKDE3ColorScheme(const QString& filePath)
 
     if (scheme->name().isEmpty())
     {
-        qDebug() << "color scheme name is not valid.";
+        //qDebug() << "color scheme name is not valid.";
         delete scheme;
         return false;
     }
@@ -651,8 +651,8 @@ bool ColorSchemeManager::loadKDE3ColorScheme(const QString& filePath)
         _colorSchemes.insert(scheme->name(),scheme);
     else
     {
-        qDebug() << "color scheme with name" << scheme->name() << "has already been" <<
-            "found, ignoring.";
+        /*qDebug() << "color scheme with name" << scheme->name() << "has already been" <<
+            "found, ignoring.";*/
         delete scheme;
     }
 
@@ -701,7 +701,7 @@ bool ColorSchemeManager::loadColorScheme(const QString& filePath)
 
     if (scheme->name().isEmpty())
     {
-        qDebug() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
+        //qDebug() << "Color scheme in" << filePath << "does not have a valid name and was not loaded.";
         delete scheme;
         return false;
     }
@@ -712,8 +712,8 @@ bool ColorSchemeManager::loadColorScheme(const QString& filePath)
     }
     else
     {
-        qDebug() << "color scheme with name" << schemeName << "has already been" <<
-            "found, ignoring.";
+        /*qDebug() << "color scheme with name" << schemeName << "has already been" <<
+            "found, ignoring.";*/
 
         delete scheme;
     }
@@ -730,7 +730,7 @@ QList<QString> ColorSchemeManager::listKDE3ColorSchemes()
         QStringList filters;
         filters << QLatin1String("*.schema");
         dir.setNameFilters(filters);
-        QStringList list = dir.entryList(filters);
+        const QStringList list = dir.entryList(filters);
         for (const QString &i : list)
             ret << dname + QLatin1Char('/') + i;
     }
@@ -750,7 +750,7 @@ QList<QString> ColorSchemeManager::listColorSchemes()
         QStringList filters;
         filters << QLatin1String("*.colorscheme");
         dir.setNameFilters(filters);
-        QStringList list = dir.entryList(filters);
+        const QStringList list = dir.entryList(filters);
         for (const QString &i : list)
             ret << dname + QLatin1Char('/') + i;
     }
@@ -777,7 +777,7 @@ bool ColorSchemeManager::deleteColorScheme(const QString& name)
     }
     else
     {
-        qDebug() << "Failed to remove color scheme -" << path;
+        //qDebug() << "Failed to remove color scheme -" << path;
         return false;
     }
 }
@@ -819,9 +819,9 @@ const ColorScheme* ColorSchemeManager::findColorScheme(const QString& name)
                 return findColorScheme(name);
         }
 
-        qDebug() << "Could not find color scheme - " << name;
+        //qDebug() << "Could not find color scheme - " << name;
 
-        return 0;
+        return nullptr;
     }
 }
 Q_GLOBAL_STATIC(ColorSchemeManager, theColorSchemeManager)
