@@ -109,6 +109,10 @@ ScreenWindow* Emulation::createWindow()
 
     connect(this , SIGNAL(outputChanged()),
             window , SLOT(notifyOutputChanged()) );
+
+    connect(this, &Emulation::handleCommandFromKeyboard,
+            window, &ScreenWindow::handleCommandFromKeyboard);
+
     return window;
 }
 
@@ -133,7 +137,7 @@ void Emulation::setScreen(int n)
   if (_currentScreen != old)
   {
      // tell all windows onto this emulation to switch to the newly active screen
-     for(ScreenWindow* window : const_cast<const QList<ScreenWindow*>&>(_windows))
+     for(ScreenWindow* window : qAsConst(_windows))
          window->setScreen(_currentScreen);
   }
 }
