@@ -24,7 +24,7 @@
 #define EMULATION_H
 
 // System
-#include <stdio.h>
+#include <cstdio>
 
 // Qt
 #include <QKeyEvent>
@@ -33,14 +33,12 @@
 #include <QTextStream>
 #include <QTimer>
 
-// Konsole
-//#include "konsole_export.h"
-#define KONSOLEPRIVATE_EXPORT
+#include "qtermwidget_export.h"
+#include "KeyboardTranslator.h"
 
 namespace Konsole
 {
 
-class KeyboardTranslator;
 class HistoryType;
 class Screen;
 class ScreenWindow;
@@ -120,7 +118,7 @@ enum
  * how long the emulation has been active/idle for and also respond to
  * a 'bell' event in different ways.
  */
-class KONSOLEPRIVATE_EXPORT Emulation : public QObject
+class QTERMWIDGET_EXPORT Emulation : public QObject
 {
 Q_OBJECT
 
@@ -148,7 +146,7 @@ public:
 
    /** Constructs a new terminal emulation */
    Emulation();
-  ~Emulation();
+  ~Emulation() override;
 
   /**
    * Creates a new window onto the output from this emulation.  The contents
@@ -444,6 +442,8 @@ signals:
    */
   void cursorChanged(KeyboardCursorShape cursorShape, bool blinkingCursorEnabled);
 
+  void handleCommandFromKeyboard(KeyboardTranslator::Command command);
+
 protected:
   virtual void setMode(int mode) = 0;
   virtual void resetMode(int mode) = 0;
@@ -452,7 +452,7 @@ protected:
    * Processes an incoming character.  See receiveData()
    * @p ch A unicode character code.
    */
-  virtual void receiveChar(int ch);
+  virtual void receiveChar(wchar_t ch);
 
   /**
    * Sets the active screen.  The terminal has two screens, primary and alternate.
