@@ -28,6 +28,7 @@
 #include <QStringList>
 #include <QWidget>
 
+#include "Emulation.h"
 #include "History.h"
 
 class KProcess;
@@ -70,8 +71,8 @@ public:
      * falls back to using the program specified in the SHELL environment
      * variable.
      */
-    Session(QObject* parent = 0);
-    virtual ~Session();
+    Session(QObject* parent = nullptr);
+    ~Session() override;
 
     /**
      * Returns true if the session is currently running.  This will be true
@@ -313,6 +314,8 @@ public:
      */
     void sendText(const QString & text) const;
 
+    void sendKeyEvent(QKeyEvent* e) const;
+
     /**
      * Returns the process id of the terminal process.
      * This is the id used by the system API to refer to the process.
@@ -477,6 +480,11 @@ signals:
      */
     void flowControlEnabledChanged(bool enabled);
 
+    /**
+     * Broker for Emulation::cursorChanged() signal
+     */
+    void cursorChanged(Emulation::KeyboardCursorShape cursorShape, bool blinkingCursorEnabled);
+
     void silence();
     void activity();
 
@@ -577,7 +585,7 @@ public:
     /** Constructs an empty session group. */
     SessionGroup();
     /** Destroys the session group and removes all connections between master and slave sessions. */
-    ~SessionGroup();
+    ~SessionGroup() override;
 
     /** Adds a session to the group. */
     void addSession( Session * session );
