@@ -25,9 +25,10 @@
 #include "Emulation.h"
 #include "Filter.h"
 #include "qtermwidget_export.h"
+#include "qtermwidget_version.h"
 
 class QVBoxLayout;
-struct TermWidgetImpl;
+class TermWidgetImpl;
 class SearchBar;
 class QUrl;
 
@@ -51,14 +52,14 @@ public:
 
     //Creation of widget
     QTermWidget(int startnow, // 1 = start shell programm immediatelly
-                QWidget * parent = 0);
+                QWidget * parent = nullptr);
     // A dummy constructor for Qt Designer. startnow is 1 by default
-    QTermWidget(QWidget *parent = 0);
+    QTermWidget(QWidget *parent = nullptr);
 
-    virtual ~QTermWidget();
+    ~QTermWidget() override;
 
     //Initial size
-    QSize sizeHint() const;
+    QSize sizeHint() const override;
 
     // expose TerminalDisplay::TerminalSizeHint, setTerminalSizeHint
     void setTerminalSizeHint(bool on);
@@ -86,7 +87,7 @@ public:
     void setTerminalFont(const QFont & font);
     QFont getTerminalFont();
     void setTerminalOpacity(qreal level);
-    void setTerminalBackgroundImage(QString backgroundImage);
+    void setTerminalBackgroundImage(const QString& backgroundImage);
 
     //environment
     void setEnvironment(const QStringList & environment);
@@ -125,6 +126,9 @@ public:
     // Send some text to terminal
     void sendText(const QString & text);
 
+    // Send key event to terminal
+    void sendKeyEvent(QKeyEvent* e);
+
     // Sets whether flow control is enabled
     void setFlowControlEnabled(bool enabled);
 
@@ -227,6 +231,10 @@ public:
 
     /** Get the empty space outside the terminal */
     int getMargin() const;
+
+    void setDrawLineChars(bool drawLineChars);
+
+    void setBoldIntense(bool boldIntense);
 signals:
     void finished();
     void copyAvailable(bool);
@@ -287,8 +295,9 @@ public slots:
 
     void toggleShowSearchBar();
 
+    void saveHistory(QIODevice *device);
 protected:
-    virtual void resizeEvent(QResizeEvent *);
+    void resizeEvent(QResizeEvent *) override;
 
 protected slots:
     void sessionFinished();
